==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QRenderTargetSelector.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a way of specifying a render target</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html">Qt3DRender::QRenderTargetSelector</a></p>
 */
public class QRenderTargetSelector extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderTargetSelector.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::targetChanged(Qt3DRender::QRenderTarget*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="target")
    public final Signal1<io.qt.qt3d.render.QRenderTarget> targetChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderTargetSelector(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderTargetSelector() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#QRenderTargetSelector">Qt3DRender::QRenderTargetSelector::QRenderTargetSelector(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderTargetSelector(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderTargetSelector instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#outputs">Qt3DRender::QRenderTargetSelector::outputs()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput.AttachmentPoint> outputs(){
        return outputs_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderTargetOutput.AttachmentPoint> outputs_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#setOutputs">Qt3DRender::QRenderTargetSelector::setOutputs(QVector&lt;QRenderTargetOutput::AttachmentPoint&gt;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setOutputs(java.util.Collection<? extends io.qt.qt3d.render.QRenderTargetOutput.AttachmentPoint> buffers){
        setOutputs_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), buffers);
    }
    
    @io.qt.QtUninvokable
    private native void setOutputs_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.qt3d.render.QRenderTargetOutput.AttachmentPoint> buffers);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::setTarget(Qt3DRender::QRenderTarget*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="target")
    public final void setTarget(io.qt.qt3d.render.QRenderTarget target){
        setTarget_native_Qt3DRender_QRenderTarget_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(target));
    }
    
    private native void setTarget_native_Qt3DRender_QRenderTarget_ptr(long __this__nativeId, long target);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::target()const</a></p>
     */
    @io.qt.QtPropertyReader(name="target")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderTarget target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QRenderTarget target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderTargetSelector(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderTargetSelector(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderTargetSelector instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.7-sources.jar: io/qt/qt3d/render/QRenderTargetSelector.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a way of specifying a render target</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qrendertargetselector.html">Qt3DRender::QRenderTargetSelector</a></p>
 */
public class QRenderTargetSelector extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderTargetSelector.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::targetChanged(Qt3DRender::QRenderTarget*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="target")
    public final Signal1<io.qt.qt3d.render.QRenderTarget> targetChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QRenderTargetSelector(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderTargetSelector() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendertargetselector.html#QRenderTargetSelector">Qt3DRender::QRenderTargetSelector::QRenderTargetSelector(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderTargetSelector(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderTargetSelector instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::setTarget(Qt3DRender::QRenderTarget*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="target")
    public final void setTarget(io.qt.qt3d.render.QRenderTarget target){
        setTarget_native_Qt3DRender_QRenderTarget_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(target));
    }
    
    private native void setTarget_native_Qt3DRender_QRenderTarget_ptr(long __this__nativeId, long target);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qrendertargetselector.html#target-prop">Qt3DRender::QRenderTargetSelector::target()const</a></p>
     */
    @io.qt.QtPropertyReader(name="target")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRenderTarget target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QRenderTarget target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderTargetSelector(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderTargetSelector(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderTargetSelector instance, QDeclarativeConstructor constructor);
    
}
